@@ -2,10 +2,9 @@ import re
 import os
 from uuid import uuid4
 
-VARIABLE_NAME = "GCP_BUCKET_NAME"
 DEFAULT_ENV = ".env"
 
-PWD = os.environ.get("PWD")
+PWD = os.environ.get("PWD") # Print Working Directory
 
 def set_env(key: str, value: str, env_file: str=DEFAULT_ENV) -> bool:
     """
